Artemis Book Sales is an independent commission sales group, representing new, remainder, and overstock wholesalers of books & related items. We sell to bookstores, universities, museum stores, and other retailers. - Artemis Book Sales

PDF Catalog
Previous Next
Children
Non-Fiction
Fiction
Non-Book
Boxed Sets
Chldren

## Featured Products

Collected Works Of James Joyce
$5.99
Kingdom of the Feared
$4.50
Eternal Tao Te Ching: The Philo
$7.99
You Are Here: Camping
$5.99
Klara & the Sun
$4.99
Lemming: That Time I Got Drunk & Yeeted A Love Potion At A Werewolf
$3.99
Rabbit Hutch
$4.99
Gilded Cage
$4.50
Pablo Neruda: Twenty Love Poems & A Song
$3.99
Troop
$3.99
Meditations
$3.99
Chambers: The Galaxy & the Ground Within
$4.50
Masterworks Orwell: 1984
$3.99
Auster: New York Trilogy
$4.99
Chandler: Long Good-bye
$4.50
World Mythology in Bite-sized Chunks
$3.99
Dylan Thomas Omnibus
$4.99
Book of English Magic
$6.99
Genius of Birds
$4.99
Chomsky: Who Rules the World
$4.99
Shinrin-yoku- Walking in the Woods
$4.99
Epic Big Nate slipcase
$14.99
Journal of the Plague Year
$3.99
Smith: White Teeth
$4.99
Dune: God Emperor of Dune
$4.99
SF Masterworks: Le Guin- Lathe Of Heaven
$3.99
Luis Borges: The Aleph
$4.50
SF Masterworks: Sirens of Titan
$3.99
Penguin Originals: Outsiders
$3.99

## Latest Products

See More
Twins of Auschwitz
$3.99
Manifestation Colouring Book
$3.99
Mermaid Colouring Book
$3.99
Naturalist In The Amazon- The Journals & Writings of Henry Walter Bates
$7.99

##### Success

Signed in successfully.

#####

Modal content

##### Modal title

Modal body text goes here.